@@ -3,6 +3,7 @@
 // SPDX-License-Identifier: MIT
 
 #[cfg(any(target_os = "macos", target_os = "windows", target_os = "linux"))]
+#[cfg(any(feature = "tray", feature = "ayatana"))]
 fn main() -> wry::Result<()> {
   use std::collections::HashMap;
   #[cfg(target_os = "linux")]
@@ -26,6 +27,7 @@ fn main() -> wry::Result<()> {
       system_tray::SystemTrayBuilder,
       window::{WindowBuilder, WindowId},
     },
+    http::ResponseBuilder,
     webview::{WebView, WebViewBuilder},
   };
 
@@ -129,8 +131,10 @@ fn main() -> wry::Result<()> {
 
       let webview = WebViewBuilder::new(window)
         .unwrap()
-        .with_custom_protocol("wry.dev".into(), move |_uri| {
-          Ok((index_html.as_bytes().into(), "text/html".into()))
+        .with_custom_protocol("wry.dev".into(), move |_request| {
+          ResponseBuilder::new()
+            .mimetype("text/html")
+            .body(index_html.as_bytes().into())
         })
         .with_url("wry.dev://")
         .unwrap()
@@ -217,3 +221,10 @@ fn main() -> wry::Result<()> {
 fn main() {
   println!("This platform doesn't support system_tray.");
 }
+
+// Tray feature flag disabled but can be available.
+#[cfg(any(target_os = "windows", target_os = "linux", target_os = "macos"))]
+#[cfg(not(any(feature = "tray", feature = "ayatana")))]
+fn main() {
+  println!("This platform doesn't have the `tray` feature enabled.");
+}
