@@ -225,12 +225,9 @@ impl InnerWebView {
       // Set user agent
       settings.set_user_agent(attributes.user_agent.as_deref());
 
-      debug_assert_eq!(
-        {
-          settings.set_enable_developer_extras(true);
-        },
-        ()
-      );
+      if attributes.devtool {
+        settings.set_enable_developer_extras(true);
+      }
     }
 
     // Transparent
@@ -314,6 +311,13 @@ impl InnerWebView {
   pub fn focus(&self) {
     self.webview.grab_focus();
   }
+
+  /// Open the web inspector which is usually called dev tool.
+  pub fn devtool(&self) {
+    if let Some(inspector) = WebViewExt::inspector(&*self.webview) {
+      inspector.show();
+    }
+  }
 }
 
 pub fn platform_webview_version() -> Result<String> {
